@@ -21,8 +21,6 @@ impl ButtonCallbackMap {
 
 #[derive(Debug, Default)]
 pub(crate) struct ButtonEventCallback {
-    pub(crate) on_press_or_release: ButtonCallbackMap,
     pub(crate) on_press: ButtonCallbackMap,
     pub(crate) on_release: ButtonCallbackMap,
-    pub(crate) on_release_alone: ButtonCallbackMap,
 }
